@@ -1,16 +1,26 @@
-import pandas as pd
+"""
+Fills in Data using data within DataFrames.
+
+Returns:
+    _DataFrame_: _The same DataFrame that was given in the function, but with filled
+    in values during the time frame specified._
+"""
+
 from datetime import datetime
+import pandas as pd
 
 def set_datetime(df):
     """
-    Takes in a DataFrame and creates year, month, and day columns for later use. Drops any existing only to avoid any key errors or copy warnings.
+    Takes in a DataFrame and creates year, month, and day columns for later use.
+    Drops any existing only to avoid any key errors or copy warnings.
 
     Args:
-        df (_DataFrame_): _The DataFrame which has a "date" column and a column which holds data to be replace._
+        df (_DataFrame_): _The DataFrame which has a "date" column and a column which
+        holds data to be replace._
 
     Returns:
         df _DataFrame_: _The original DataFrame with new year, month, and day columns._
-    """
+        """
     df = df.drop(['year','month','day'], axis=1, errors='ignore')
     df = df.drop(['Year','Month','Day'], axis=1, errors='ignore')
     df = df.drop(['YEAR','MONTH','DAY'], axis=1, errors='ignore')
@@ -21,7 +31,7 @@ def set_datetime(df):
         df['month'] = df['date'].dt.month
         df['day'] = df['date'].dt.day
         df.set_index('date',inplace=True)
-        
+
     except:
         df.reset_index(inplace=True)
         df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
@@ -31,26 +41,31 @@ def set_datetime(df):
         df.set_index('date',inplace=True)
 
     return df
-    
+
 def make_testing(df, start_date, end_date, to_replace):
     """
-    Creates a temporary DataFrame which will hold information to fill in the permanent DataFrame.
+    Creates a temporary DataFrame which will hold information to fill in the permanent
+    DataFrame.
 
     Args:
-        df (_DataFrame_): _A DataFrame which has a 'date' column in datetime format and a column which has data that will be used in filling in missing data._
-        start_date (_string_): _A date string for the start of the data that needs to be replaced._
-        end_date (_string_): _A date string for the end of the data that needs to be replaced._
-        to_replace (_DataFrame_): _A temporary DataFrame which will hold the data used to create values to fill in missing or incorrect data._
+    df (_DataFrame_): _A DataFrame which has a 'date' column in datetime format and
+    a column which has data that will be used in filling in missing data._
+    start_date (_string_): _A date string for the start of the data that needs to be
+    replaced._
+    end_date (_string_): _A date string for the end of the data that needs to be
+    replaced._
+    to_replace (_DataFrame_): _A temporary DataFrame which will hold the data used
+    to create values to fill in missing or incorrect data._
 
     Returns:
-        _DataFrame_: _A temporary DataFrame that will be used to fill in missing data._
+    _DataFrame_: _A temporary DataFrame that will be used to fill in missing data._
     """
     start_time = datetime.strptime(start_date, '%Y-%m-%d')
     end_time = datetime.strptime(end_date, '%Y-%m-%d')
 
     start_year = start_time.year - 5
     end_year = end_time.year + 6
-    
+
     start_day =  start_time.day
     start_month = start_time.month
 
@@ -58,7 +73,7 @@ def make_testing(df, start_date, end_date, to_replace):
     end_month = end_time.month
 
     year_diff = end_time.year - start_time.year
-    
+
     testing_data = []
 
     for year in range(start_year, end_year):
@@ -70,36 +85,44 @@ def make_testing(df, start_date, end_date, to_replace):
     testing_df = testing_df[~testing_df.index.duplicated(keep='first')]
     testing_df.drop(labels=to_replace.index, inplace=True)
     testing_df['month_day'] = (testing_df['month']).astype(str) + "_" + (testing_df['day']).astype(str)
-        
+
     return testing_df
-    
+
 def fill_data(df, column, start_date, end_date):
     """
-    Takes in a DataFrame, column to fill (str), and two date strings in 'YYYY-mm-dd' format and returns the column filled with data which is the average of the decade that surrounds the chosen dates. 
+    Takes in a DataFrame, column to fill (str), and two date strings in 'YYYY-mm-dd'
+    format and returns the column filled with data which is the average of the decade
+    that surrounds the chosen dates.
     
-    DataFrame must contain a column labelled 'date' (CASE SENSITIVE). Regardless of format, the dates within the 'date' column should be listed in year,month,day order i.e.:
+    DataFrame must contain a column labelled 'date' (CASE SENSITIVE). Regardless of
+    format, the dates within the 'date' column should be listed in year,month,day order
+    i.e.:
     
     YYYYmmdd, YYYY/mm/dd, YYYY-mm-dd or any matching order regardless of separator.
 
 
     Args:
-        df (_DataFrame_): _A DataFrame with a column labelled exactly 'date' with Datetime information and a column that you wish to replace._
-        column (_string_): _The name of the column that you wish to be filled._
-        start_date (_string_): _The beginning of the dates that you wish to replace. YYYY-mm-dd format._
-        end_date (_string_): _The ending of the dates that you wish to replace. YYYY-mm-dd format._
+    df (_DataFrame_): _A DataFrame with a column labelled exactly 'date' with
+    Datetime information and a column that you wish to replace._
+    column (_string_): _The name of the column that you wish to be filled._
+    start_date (_string_): _The beginning of the dates that you wish to replace.
+    YYYY-mm-dd format._
+    end_date (_string_): _The ending of the dates that you wish to replace.
+    YYYY-mm-dd format._
 
     Returns:
-        _DataFrame_: _The original DataFrame with new year, month, and day columns as well as filled in data in the Date range specified._
+    _DataFrame_: _The original DataFrame with new year, month, and day columns as
+    well as filled in data in the Date range specified._
     """
-    
+
     df = set_datetime(df)
-    
+
     to_replace = df.loc[start_date:end_date].copy()
-    
+
     testing_df = make_testing(df, start_date, end_date, to_replace)
-    
+
     to_replace['month_day'] = (to_replace['month']).astype(str) + "_" + (to_replace['day']).astype(str)
-    
+
     gb = testing_df.groupby(['month_day'])[column].mean().reset_index()
 
     month_day = gb['month_day'].values
@@ -112,5 +135,5 @@ def fill_data(df, column, start_date, end_date):
     df = df[~df.index.duplicated(keep='last')]
     df = df.drop('month_day', axis=1)
     df = df.sort_index()
-    
+
     return df
